@@ -19,23 +19,23 @@
 
 #include "tablethandler.h"
 
-#include "tabletbackendinterface.h"
-#include "tabletbackendfactory.h"
-#include "tabletinfo.h"
 #include "devicetype.h"
 #include "screenmap.h"
 #include "screenspace.h"
 #include "stringutils.h"
+#include "tabletbackendfactory.h"
+#include "tabletbackendinterface.h"
+#include "tabletinfo.h"
 
 // common includes
-#include "logging.h"
 #include "deviceprofile.h"
-#include "tabletdatabase.h"
+#include "logging.h"
 #include "mainconfig.h"
-#include "profilemanager.h"
 #include "profilemanagement.h"
-#include "tabletprofile.h"
+#include "profilemanager.h"
 #include "screensinfo.h"
+#include "tabletdatabase.h"
+#include "tabletprofile.h"
 
 #include <QGuiApplication>
 #include <QList>
@@ -43,43 +43,42 @@
 
 #include <KLocalizedString>
 
-
 namespace Wacom
 {
-    class TabletHandlerPrivate
-    {
-        public:
-            MainConfig                               mainConfig;            //!< Main config file which stores general parameters.
-            QString                                  profileFile;           //!< Save which profile we should use
-            QHash<QString, ProfileManager *>         profileManagerList;    //!< Profile manager which reads profile configuration from file.
-            QHash<QString, TabletBackendInterface *> tabletBackendList;     //!< Tablet backend of all currently connected tablets.
-            QHash<QString, TabletInformation>        tabletInformationList; //!< Information of all currently connected tablets.
-            QHash<QString, QString>                  currentProfileList;    //!< Currently active profile for each tablet.
-    }; // CLASS
+class TabletHandlerPrivate
+{
+public:
+    MainConfig mainConfig; //!< Main config file which stores general parameters.
+    QString profileFile; //!< Save which profile we should use
+    QHash<QString, ProfileManager *> profileManagerList; //!< Profile manager which reads profile configuration from file.
+    QHash<QString, TabletBackendInterface *> tabletBackendList; //!< Tablet backend of all currently connected tablets.
+    QHash<QString, TabletInformation> tabletInformationList; //!< Information of all currently connected tablets.
+    QHash<QString, QString> currentProfileList; //!< Currently active profile for each tablet.
+}; // CLASS
 } // NAMESPACE
 
 using namespace Wacom;
 
 TabletHandler::TabletHandler()
-    : TabletHandlerInterface(nullptr), d_ptr(new TabletHandlerPrivate)
+    : TabletHandlerInterface(nullptr)
+    , d_ptr(new TabletHandlerPrivate)
 {
-    Q_D( TabletHandler );
+    Q_D(TabletHandler);
 
     d->profileFile = QLatin1String("tabletprofilesrc");
     d->mainConfig.open(QLatin1String("wacomtablet-kderc"));
 }
 
-
-TabletHandler::TabletHandler(const QString& profileFile, const QString configFile)
-    : TabletHandlerInterface(nullptr), d_ptr(new TabletHandlerPrivate)
+TabletHandler::TabletHandler(const QString &profileFile, const QString configFile)
+    : TabletHandlerInterface(nullptr)
+    , d_ptr(new TabletHandlerPrivate)
 {
-    Q_D( TabletHandler );
+    Q_D(TabletHandler);
 
     d->profileFile = profileFile;
     d->mainConfig.open(configFile);
 }
 
-
 TabletHandler::~TabletHandler()
 {
     qDeleteAll(d_ptr->tabletBackendList);
@@ -87,41 +86,35 @@ TabletHandler::~TabletHandler()
     delete d_ptr;
 }
 
-
-
-QString TabletHandler::getProperty(const QString &tabletId, const DeviceType& deviceType, const Property& property) const
+QString TabletHandler::getProperty(const QString &tabletId, const DeviceType &deviceType, const Property &property) const
 {
-    Q_D( const TabletHandler );
+    Q_D(const TabletHandler);
 
-    if( !d->tabletBackendList.contains(tabletId) || d->tabletBackendList.value(tabletId) == nullptr) {
-        qCWarning(KDED) << QString::fromLatin1("Unable to get property '%1' from device '%2' as no device is currently available!").arg(property.key()).arg(deviceType.key());
+    if (!d->tabletBackendList.contains(tabletId) || d->tabletBackendList.value(tabletId) == nullptr) {
+        qCWarning(KDED) << QString::fromLatin1("Unable to get property '%1' from device '%2' as no device is currently available!")
+                               .arg(property.key())
+                               .arg(deviceType.key());
         return QString();
     }
 
-    return d->tabletBackendList.value(tabletId)->getProperty( deviceType, property );
+    return d->tabletBackendList.value(tabletId)->getProperty(deviceType, property);
 }
 
-
-void TabletHandler::onTabletAdded( const TabletInformation& info )
+void TabletHandler::onTabletAdded(const TabletInformation &info)
 {
-    Q_D( TabletHandler );
+    Q_D(TabletHandler);
 
     // if we already have a device ... skip this step
     QString tabletId = info.get(TabletInfo::TabletId);
-    if(d->tabletBackendList.contains(tabletId)) {
-        qCDebug(KDED) << QString::fromLatin1("Ignoring tablet '%1' as another one with same name is already connected.")
-                    .arg(info.get(TabletInfo::TabletId));
+    if (d->tabletBackendList.contains(tabletId)) {
+        qCDebug(KDED) << QString::fromLatin1("Ignoring tablet '%1' as another one with same name is already connected.").arg(info.get(TabletInfo::TabletId));
         return;
     }
 
-    qCDebug(KDED) << "Taking control of new tablet" << info.get(TabletInfo::TabletName)
-             << "(" << info.get(TabletInfo::TabletId) << ") ["
-             << (info.hasDevice(DeviceType::Stylus) ? "stylus" : "")
-             << (info.hasDevice(DeviceType::Eraser) ? "eraser" : "")
-             << (info.hasDevice(DeviceType::Pad)    ? "pad"    : "")
-             << (info.hasDevice(DeviceType::Touch)  ? "touch"  : "")
-             << (info.hasDevice(DeviceType::Cursor) ? "cursor" : "")
-             << "]";
+    qCDebug(KDED) << "Taking control of new tablet" << info.get(TabletInfo::TabletName) << "(" << info.get(TabletInfo::TabletId) << ") ["
+                  << (info.hasDevice(DeviceType::Stylus) ? "stylus" : "") << (info.hasDevice(DeviceType::Eraser) ? "eraser" : "")
+                  << (info.hasDevice(DeviceType::Pad) ? "pad" : "") << (info.hasDevice(DeviceType::Touch) ? "touch" : "")
+                  << (info.hasDevice(DeviceType::Cursor) ? "cursor" : "") << "]";
 
     // create tablet backend
     TabletBackendInterface *tbi = TabletBackendFactory::createBackend(info);
@@ -138,10 +131,7 @@ void TabletHandler::onTabletAdded( const TabletInformation& info )
     d->tabletInformationList.insert(tabletId, info);
 
     // if we found something notify about it and set the default profile to it
-    emit notify(QLatin1String("tabletAdded"),
-                i18n("Tablet Connected"),
-                i18n("New tablet '%1' connected.", info.get(TabletInfo::TabletName)),
-                true);
+    emit notify(QLatin1String("tabletAdded"), i18n("Tablet Connected"), i18n("New tablet '%1' connected.", info.get(TabletInfo::TabletName)), true);
 
     // set profile which was last used
     auto lastProfile = d->mainConfig.getLastProfile(info.getUniqueDeviceId());
@@ -159,20 +149,15 @@ void TabletHandler::onTabletAdded( const TabletInformation& info )
     emit tabletAdded(info);
 }
 
-
-
-void TabletHandler::onTabletRemoved( const TabletInformation& info )
+void TabletHandler::onTabletRemoved(const TabletInformation &info)
 {
-    Q_D( TabletHandler );
+    Q_D(TabletHandler);
 
     TabletBackendInterface *tbi = d->tabletBackendList.value(info.get(TabletInfo::TabletId));
-    TabletInformation       ti  = d->tabletInformationList.value(info.get(TabletInfo::TabletId));
+    TabletInformation ti = d->tabletInformationList.value(info.get(TabletInfo::TabletId));
 
-    if ( tbi && ti.getTabletSerial() == info.getTabletSerial() ) {
-        emit notify(QLatin1String("tabletRemoved"),
-                    i18n("Tablet removed"),
-                    i18n("Tablet %1 removed", ti.get(TabletInfo::TabletName)),
-                    false);
+    if (tbi && ti.getTabletSerial() == info.getTabletSerial()) {
+        emit notify(QLatin1String("tabletRemoved"), i18n("Tablet removed"), i18n("Tablet %1 removed", ti.get(TabletInfo::TabletName)), false);
 
         QString tabletId = info.get(TabletInfo::TabletId);
         d->tabletBackendList.remove(tabletId);
@@ -185,22 +170,19 @@ void TabletHandler::onTabletRemoved( const TabletInformation& info )
     }
 }
 
-
-
 void TabletHandler::onScreenRotated(QString output, const Qt::ScreenOrientation &newScreenRotation)
 {
-    Q_D( TabletHandler );
+    Q_D(TabletHandler);
 
     qCDebug(KDED) << "Screen" << output << "rotation has changed to" << newScreenRotation;
 
-    //for each connected tablet, do the rotation
-    foreach(const QString &tabletId, d->tabletInformationList.keys()) {
+    // for each connected tablet, do the rotation
+    foreach (const QString &tabletId, d->tabletInformationList.keys()) {
         QString curProfile = d->currentProfileList.value(tabletId);
         TabletProfile tabletProfile = d->profileManagerList.value(tabletId)->loadProfile(curProfile);
         ScreenRotation screenRotation = ScreenRotation::NONE;
 
-        switch (newScreenRotation)
-        {
+        switch (newScreenRotation) {
         case Qt::PrimaryOrientation:
         case Qt::LandscapeOrientation:
             screenRotation = ScreenRotation::NONE;
@@ -226,12 +208,12 @@ void TabletHandler::onScreenRotated(QString output, const Qt::ScreenOrientation
 
 void TabletHandler::onScreenAddedRemoved(QScreen *screen)
 {
-    Q_D( TabletHandler );
+    Q_D(TabletHandler);
 
     Q_UNUSED(screen)
     qCDebug(KDED) << "Number of screens has changed";
 
-    foreach(const QString &tabletId, d->tabletInformationList.keys()) {
+    foreach (const QString &tabletId, d->tabletInformationList.keys()) {
         QString curProfile = d->currentProfileList.value(tabletId);
         TabletProfile tabletProfile = d->profileManagerList.value(tabletId)->loadProfile(curProfile);
 
@@ -241,11 +223,11 @@ void TabletHandler::onScreenAddedRemoved(QScreen *screen)
 
 void TabletHandler::onScreenGeometryChanged()
 {
-    Q_D( TabletHandler );
+    Q_D(TabletHandler);
 
     qCDebug(KDED) << "Screen geometry has changed";
 
-    foreach(const QString &tabletId, d->tabletInformationList.keys()) {
+    foreach (const QString &tabletId, d->tabletInformationList.keys()) {
         QString curProfile = d->currentProfileList.value(tabletId);
         TabletProfile tabletProfile = d->profileManagerList.value(tabletId)->loadProfile(curProfile);
 
@@ -253,13 +235,12 @@ void TabletHandler::onScreenGeometryChanged()
     }
 }
 
-
 void TabletHandler::onTogglePenMode()
 {
-    Q_D( TabletHandler );
+    Q_D(TabletHandler);
 
-    foreach(const QString &tabletId, d->tabletInformationList.keys()) {
-        if( !hasTablet(tabletId) || !hasDevice(tabletId, DeviceType::Stylus)) {
+    foreach (const QString &tabletId, d->tabletInformationList.keys()) {
+        if (!hasTablet(tabletId) || !hasDevice(tabletId, DeviceType::Stylus)) {
             continue;
         }
 
@@ -268,7 +249,7 @@ void TabletHandler::onTogglePenMode()
         TabletProfile tabletProfile = d->profileManagerList.value(tabletId)->loadProfile(curProfile);
         DeviceProfile stylusProfile = tabletProfile.getDevice(DeviceType::Stylus);
 
-        QString     trackingMode = stylusProfile.getProperty(Property::Mode);
+        QString trackingMode = stylusProfile.getProperty(Property::Mode);
         ScreenSpace screenSpace(stylusProfile.getProperty(Property::ScreenSpace));
 
         // toggle tracking mode
@@ -279,7 +260,7 @@ void TabletHandler::onTogglePenMode()
             // as screen mappings are not supported in absolute mode
             // XXX: this doesn't seem to be nescessary?
             trackingMode = QLatin1String("relative");
-            //screenSpace  = ScreenSpace::desktop();
+            // screenSpace  = ScreenSpace::desktop();
         }
 
         // map tablet to output which will also save the current mode in the profile
@@ -290,14 +271,12 @@ void TabletHandler::onTogglePenMode()
     }
 }
 
-
-
 void TabletHandler::onToggleTouch()
 {
-    Q_D( TabletHandler );
+    Q_D(TabletHandler);
 
-    foreach(const QString &tabletId, d->tabletInformationList.keys()) {
-        if( !hasDevice(tabletId, DeviceType::Touch) ) {
+    foreach (const QString &tabletId, d->tabletInformationList.keys()) {
+        if (!hasDevice(tabletId, DeviceType::Touch)) {
             continue;
         }
 
@@ -309,12 +288,12 @@ void TabletHandler::onToggleTouch()
         TabletProfile tabletProfile = d->profileManagerList.value(tabletId)->loadProfile(curProfile);
         DeviceProfile touchProfile = tabletProfile.getDevice(DeviceType::Touch);
 
-        if( touchMode.compare( QLatin1String( "off" ), Qt::CaseInsensitive) == 0 ) {
+        if (touchMode.compare(QLatin1String("off"), Qt::CaseInsensitive) == 0) {
             setProperty(tabletId, DeviceType::Touch, Property::Touch, QLatin1String("on"));
-            touchProfile.setProperty( Property::Touch, QLatin1String("on" ) );
+            touchProfile.setProperty(Property::Touch, QLatin1String("on"));
         } else {
             setProperty(tabletId, DeviceType::Touch, Property::Touch, QLatin1String("off"));
-            touchProfile.setProperty( Property::Touch, QLatin1String("off") );
+            touchProfile.setProperty(Property::Touch, QLatin1String("off"));
         }
 
         tabletProfile.setDevice(touchProfile);
@@ -322,54 +301,48 @@ void TabletHandler::onToggleTouch()
     }
 }
 
-
 void TabletHandler::onToggleScreenMapping()
 {
-    Q_D( TabletHandler );
+    Q_D(TabletHandler);
 
-    foreach(const QString &tabletId, d->tabletInformationList.keys()) {
+    foreach (const QString &tabletId, d->tabletInformationList.keys()) {
         if (!hasTablet(tabletId)) {
             continue;
         }
 
         QString curProfile = d->currentProfileList.value(tabletId);
         TabletProfile tabletProfile = d->profileManagerList.value(tabletId)->loadProfile(curProfile);
-        DeviceProfile stylusProfile  = tabletProfile.getDevice(DeviceType::Stylus);
-        ScreenSpace   screenSpace    = ScreenSpace(stylusProfile.getProperty(Property::ScreenSpace));
+        DeviceProfile stylusProfile = tabletProfile.getDevice(DeviceType::Stylus);
+        ScreenSpace screenSpace = ScreenSpace(stylusProfile.getProperty(Property::ScreenSpace));
 
         mapPenToScreenSpace(tabletId, screenSpace.next());
     }
 }
 
-
 void TabletHandler::onMapToFullScreen()
 {
-    Q_D( TabletHandler );
+    Q_D(TabletHandler);
 
-    foreach(const QString &tabletId, d->tabletInformationList.keys()) {
+    foreach (const QString &tabletId, d->tabletInformationList.keys()) {
         mapPenToScreenSpace(tabletId, ScreenSpace::desktop().toString());
     }
 }
 
-
-
 void TabletHandler::onMapToScreen1()
 {
-    Q_D( TabletHandler );
+    Q_D(TabletHandler);
 
-    foreach(const QString &tabletId, d->tabletInformationList.keys()) {
+    foreach (const QString &tabletId, d->tabletInformationList.keys()) {
         mapPenToScreenSpace(tabletId, ScreenSpace::monitor(ScreensInfo::getPrimaryScreenName()));
     }
 }
 
-
-
 void TabletHandler::onMapToScreen2()
 {
-    Q_D( TabletHandler );
+    Q_D(TabletHandler);
 
     if (QGuiApplication::screens().count() > 1) {
-        foreach(const QString &tabletId, d->tabletInformationList.keys()) {
+        foreach (const QString &tabletId, d->tabletInformationList.keys()) {
             mapPenToScreenSpace(tabletId, ScreenSpace::monitor(ScreensInfo::getPrimaryScreenName()).next());
         }
     }
@@ -377,13 +350,12 @@ void TabletHandler::onMapToScreen2()
 
 void TabletHandler::onNextProfile()
 {
-    Q_D( TabletHandler );
+    Q_D(TabletHandler);
 
-    foreach(const QString &tabletId, d->tabletInformationList.keys()) {
-        if(d->profileManagerList.value(tabletId)->profileRotationList().empty()) {
+    foreach (const QString &tabletId, d->tabletInformationList.keys()) {
+        if (d->profileManagerList.value(tabletId)->profileRotationList().empty()) {
             qCDebug(KDED) << "No items in the rotation list. Nothing to rotate";
-        }
-        else {
+        } else {
             QString nextProfile = d->profileManagerList.value(tabletId)->nextProfile();
             setProfile(tabletId, nextProfile);
         }
@@ -392,25 +364,24 @@ void TabletHandler::onNextProfile()
 
 void TabletHandler::onPreviousProfile()
 {
-    Q_D( TabletHandler );
+    Q_D(TabletHandler);
 
-    foreach(const QString &tabletId, d->tabletInformationList.keys()) {
-        if(d->profileManagerList.value(tabletId)->profileRotationList().empty()) {
+    foreach (const QString &tabletId, d->tabletInformationList.keys()) {
+        if (d->profileManagerList.value(tabletId)->profileRotationList().empty()) {
             qCDebug(KDED) << "No items in the rotation list. Nothing to rotate";
-        }
-        else {
+        } else {
             QString previousProfile = d->profileManagerList.value(tabletId)->previousProfile();
             setProfile(tabletId, previousProfile);
         }
     }
 }
 
-QStringList TabletHandler::listProfiles( const QString &tabletId )
+QStringList TabletHandler::listProfiles(const QString &tabletId)
 {
-    Q_D( TabletHandler );
+    Q_D(TabletHandler);
 
     ProfileManager *pm = d->profileManagerList.value(tabletId);
-    if(!pm) {
+    if (!pm) {
         qCWarning(KDED) << "Could not retrieve ProfileManager for tablet" << tabletId;
         return QStringList();
     }
@@ -420,11 +391,9 @@ QStringList TabletHandler::listProfiles( const QString &tabletId )
     return pm->listProfiles();
 }
 
-
-
-void TabletHandler::setProfile( const QString &tabletId, const QString &profile )
+void TabletHandler::setProfile(const QString &tabletId, const QString &profile)
 {
-    Q_D( TabletHandler );
+    Q_D(TabletHandler);
 
     qCDebug(KDED) << QString::fromLatin1("Loading tablet profile '%1' for device '%2'...").arg(profile).arg(tabletId);
 
@@ -435,43 +404,38 @@ void TabletHandler::setProfile( const QString &tabletId, const QString &profile
 
     ProfileManager *profileManager = d->profileManagerList.value(tabletId);
 
-    if(!profileManager) {
+    if (!profileManager) {
         qCWarning(KDED) << "Could not retrieve ProfileManager for tablet" << tabletId;
         return;
     }
 
     TabletInformation tabletInformation = d->tabletInformationList.value(tabletId);
-    profileManager->readProfiles(tabletInformation.getUniqueDeviceId(),
-                                 tabletInformation.getLegacyUniqueDeviceId());
+    profileManager->readProfiles(tabletInformation.getUniqueDeviceId(), tabletInformation.getLegacyUniqueDeviceId());
     TabletProfile tabletProfile = profileManager->loadProfile(profile);
 
     if (tabletProfile.listDevices().isEmpty()) {
-        //may happen also if "last selected profile" was deleted.
-        //thus we check if any profile exist and take the first one
-        // or create a new empty profile and apply this instead
+        // may happen also if "last selected profile" was deleted.
+        // thus we check if any profile exist and take the first one
+        //  or create a new empty profile and apply this instead
         QStringList pList = profileManager->listProfiles();
 
-        if(pList.isEmpty()) {
+        if (pList.isEmpty()) {
             // create a new default profile
             const QString vendorId = tabletInformation.get(TabletInfo::CompanyId);
             const QString deviceName = QString::fromLatin1("%1:%2").arg(vendorId).arg(tabletId);
-            ProfileManagement* profileManagement =
-                &ProfileManagement::instance(deviceName,
-                                             tabletInformation.hasDevice(DeviceType::Touch));
-            profileManagement->createNewProfile(i18nc( "Name of the default profile that will be created if none exists.","Default" ));
+            ProfileManagement *profileManagement = &ProfileManagement::instance(deviceName, tabletInformation.hasDevice(DeviceType::Touch));
+            profileManagement->createNewProfile(i18nc("Name of the default profile that will be created if none exists.", "Default"));
 
-            if(!profileManagement->availableProfiles().empty()) {
+            if (!profileManagement->availableProfiles().empty()) {
                 d->currentProfileList.insert(tabletId, profileManagement->availableProfiles().first());
-            }
-            else {
+            } else {
                 qCWarning(KDED) << "Could not create new default profile. There seems to be an error on device detection";
             }
-        }
-        else {
+        } else {
             qCWarning(KDED) << QString::fromLatin1("Tablet profile '%1' does not exist!").arg(profile);
-            emit notify(QLatin1String( "tabletError"),
-                        i18n( "Graphic Tablet error" ),
-                        i18n( "Profile <b>%1</b> does not exist. Apply <b>%2</b> instead", profile, pList.first() ),
+            emit notify(QLatin1String("tabletError"),
+                        i18n("Graphic Tablet error"),
+                        i18n("Profile <b>%1</b> does not exist. Apply <b>%2</b> instead", profile, pList.first()),
                         true);
 
             // set first known profile instead
@@ -479,8 +443,7 @@ void TabletHandler::setProfile( const QString &tabletId, const QString &profile
         }
 
         tabletProfile = profileManager->loadProfile(d->currentProfileList.value(tabletId));
-    }
-    else {
+    } else {
         // set profile
         d->currentProfileList.insert(tabletId, profile);
     }
@@ -501,10 +464,10 @@ void TabletHandler::setProfile( const QString &tabletId, const QString &profile
 
     // check profile rotation values and LEDs
     profileManager->updateCurrentProfileNumber(currentProfile);
-    d->tabletBackendList.value(tabletId)->setStatusLED( profileManager->profileNumber( currentProfile ));
-    d->tabletBackendList.value(tabletId)->setStatusLEDBrightness( 32 ); // TODO: Read the brightness from the settings. Add support to the kcmodule GUI for that.
+    d->tabletBackendList.value(tabletId)->setStatusLED(profileManager->profileNumber(currentProfile));
+    d->tabletBackendList.value(tabletId)->setStatusLEDBrightness(32); // TODO: Read the brightness from the settings. Add support to the kcmodule GUI for that.
 
-    emit profileChanged( tabletId, currentProfile );
+    emit profileChanged(tabletId, currentProfile);
 
     QString touchSensorId = tabletInformation.get(TabletInfo::TouchSensorId);
     // TODO: check if for some reason someone will make an infinitely nested tablets
@@ -513,15 +476,15 @@ void TabletHandler::setProfile( const QString &tabletId, const QString &profile
     }
 }
 
-
-
-void TabletHandler::setProperty(const QString &tabletId, const DeviceType& deviceType,
-                                const Property& property, const QString& value)
+void TabletHandler::setProperty(const QString &tabletId, const DeviceType &deviceType, const Property &property, const QString &value)
 {
-    Q_D( TabletHandler );
+    Q_D(TabletHandler);
 
     if (!hasTablet(tabletId)) {
-        qCWarning(KDED) << QString::fromLatin1("Unable to set property '%1' on device '%2' to '%3' as no device is currently available!").arg(property.key()).arg(deviceType.key()).arg(value);
+        qCWarning(KDED) << QString::fromLatin1("Unable to set property '%1' on device '%2' to '%3' as no device is currently available!")
+                               .arg(property.key())
+                               .arg(deviceType.key())
+                               .arg(value);
         return;
     }
 
@@ -530,7 +493,7 @@ void TabletHandler::setProperty(const QString &tabletId, const DeviceType& devic
 
 QStringList TabletHandler::getProfileRotationList(const QString &tabletId)
 {
-    Q_D( TabletHandler );
+    Q_D(TabletHandler);
 
     if (!hasTablet(tabletId)) {
         qCWarning(KDED) << QString::fromLatin1("Unable to get profile rotation list as no device is currently available!");
@@ -542,7 +505,7 @@ QStringList TabletHandler::getProfileRotationList(const QString &tabletId)
 
 void TabletHandler::setProfileRotationList(const QString &tabletId, const QStringList &rotationList)
 {
-    Q_D( TabletHandler );
+    Q_D(TabletHandler);
 
     if (!hasTablet(tabletId)) {
         qCWarning(KDED) << QString::fromLatin1("Unable to set profile rotation list as no device is currently available!");
@@ -552,21 +515,17 @@ void TabletHandler::setProfileRotationList(const QString &tabletId, const QStrin
     d->profileManagerList.value(tabletId)->setProfileRotationList(rotationList);
 }
 
-void TabletHandler::autoRotateTablet(const QString &tabletId,
-                                     const TabletProfile &tabletProfile,
-                                     QString output,
-                                     ScreenRotation screenRotation)
+void TabletHandler::autoRotateTablet(const QString &tabletId, const TabletProfile &tabletProfile, QString output, ScreenRotation screenRotation)
 {
     // determine auto-rotation configuration
-    DeviceProfile         stylusProfile    = tabletProfile.getDevice(DeviceType::Stylus);
+    DeviceProfile stylusProfile = tabletProfile.getDevice(DeviceType::Stylus);
 
-    QString               rotateProperty   = stylusProfile.getProperty(Property::Rotate);
-    const ScreenRotation* lookupRotation   = ScreenRotation::find(rotateProperty);
-    ScreenRotation        tabletRotation   = (lookupRotation != nullptr) ?
-                                                *lookupRotation : ScreenRotation::NONE;
+    QString rotateProperty = stylusProfile.getProperty(Property::Rotate);
+    const ScreenRotation *lookupRotation = ScreenRotation::find(rotateProperty);
+    ScreenRotation tabletRotation = (lookupRotation != nullptr) ? *lookupRotation : ScreenRotation::NONE;
 
-    bool                  doAutoInvert     = (tabletRotation == ScreenRotation::AUTO_INVERTED);
-    bool                  doAutoRotation   = (doAutoInvert || tabletRotation == ScreenRotation::AUTO);
+    bool doAutoInvert = (tabletRotation == ScreenRotation::AUTO_INVERTED);
+    bool doAutoRotation = (doAutoInvert || tabletRotation == ScreenRotation::AUTO);
 
     if (!doAutoRotation) {
         qCDebug(KDED) << "Auto-rotation is disabled in profile settings";
@@ -591,39 +550,33 @@ void TabletHandler::autoRotateTablet(const QString &tabletId,
 
     qCDebug(KDED) << "Rotate tablet :: " << newRotation.key();
 
-    setProperty( tabletId, DeviceType::Stylus, Property::Rotate, newRotation.key() );
-    setProperty( tabletId, DeviceType::Eraser, Property::Rotate, newRotation.key() );
+    setProperty(tabletId, DeviceType::Stylus, Property::Rotate, newRotation.key());
+    setProperty(tabletId, DeviceType::Eraser, Property::Rotate, newRotation.key());
 
-    if(hasDevice(tabletId, DeviceType::Touch)) {
-        setProperty( tabletId, DeviceType::Touch, Property::Rotate, newRotation.key() );
+    if (hasDevice(tabletId, DeviceType::Touch)) {
+        setProperty(tabletId, DeviceType::Touch, Property::Rotate, newRotation.key());
     }
 }
 
-
-bool TabletHandler::hasDevice(const QString &tabletId, const DeviceType& type) const
+bool TabletHandler::hasDevice(const QString &tabletId, const DeviceType &type) const
 {
-    Q_D( const TabletHandler );
+    Q_D(const TabletHandler);
 
-    return (hasTablet(tabletId) &&
-            d->tabletInformationList.value(tabletId).hasDevice(type));
+    return (hasTablet(tabletId) && d->tabletInformationList.value(tabletId).hasDevice(type));
 }
 
-
-
 bool TabletHandler::hasTablet(const QString &tabletId) const
 {
-    Q_D( const TabletHandler );
+    Q_D(const TabletHandler);
 
-    return (d->tabletBackendList.contains(tabletId) &&
-            d->tabletBackendList.value(tabletId) != nullptr);
+    return (d->tabletBackendList.contains(tabletId) && d->tabletBackendList.value(tabletId) != nullptr);
 }
 
-
 void TabletHandler::mapDeviceToOutput(const QString &tabletId,
-                                      const DeviceType& device,
-                                      const ScreenSpace& screenSpace,
-                                      const QString& trackingMode,
-                                      TabletProfile& tabletProfile)
+                                      const DeviceType &device,
+                                      const ScreenSpace &screenSpace,
+                                      const QString &trackingMode,
+                                      TabletProfile &tabletProfile)
 {
     if (!hasTablet(tabletId) || !hasDevice(tabletId, device)) {
         return; // we do not have a tablet or the requested device
@@ -635,18 +588,14 @@ void TabletHandler::mapDeviceToOutput(const QString &tabletId,
     // however do not override this in the saved profile, because it breaks user
     // settings if they disconnect external tablet
     const bool screen_is_valid =
-        !screen.isMonitor() ||
-        (QGuiApplication::screens().count() > 1 &&
-         ScreensInfo::getScreenGeometries().contains(screen.toString()));
+        !screen.isMonitor() || (QGuiApplication::screens().count() > 1 && ScreensInfo::getScreenGeometries().contains(screen.toString()));
 
     DeviceProfile deviceProfile = tabletProfile.getDevice(device);
     ScreenMap screenMap(deviceProfile.getProperty(Property::ScreenMap));
     QString tabletArea = screenMap.getMappingAsString(screen);
 
     setProperty(tabletId, device, Property::Mode, trackingMode);
-    setProperty(tabletId, device, Property::ScreenSpace,
-                screen_is_valid ? screen.toString()
-                    : ScreenSpace::desktop().toString());
+    setProperty(tabletId, device, Property::ScreenSpace, screen_is_valid ? screen.toString() : ScreenSpace::desktop().toString());
     setProperty(tabletId, device, Property::Area, tabletArea);
 
     deviceProfile.setProperty(Property::Mode, trackingMode);
@@ -656,20 +605,16 @@ void TabletHandler::mapDeviceToOutput(const QString &tabletId,
     tabletProfile.setDevice(deviceProfile);
 }
 
-
-
-void TabletHandler::mapPenToScreenSpace(const QString &tabletId,
-                                        const ScreenSpace& screenSpace,
-                                        const QString& trackingMode)
+void TabletHandler::mapPenToScreenSpace(const QString &tabletId, const ScreenSpace &screenSpace, const QString &trackingMode)
 {
-    Q_D( TabletHandler );
+    Q_D(TabletHandler);
 
     if (!hasTablet(tabletId)) {
         return; // we do not have a tablet
     }
 
     QString curProfile = d->currentProfileList.value(tabletId);
-    TabletProfile tabletProfile  = d->profileManagerList.value(tabletId)->loadProfile(curProfile);
+    TabletProfile tabletProfile = d->profileManagerList.value(tabletId)->loadProfile(curProfile);
 
     mapDeviceToOutput(tabletId, DeviceType::Stylus, screenSpace, trackingMode, tabletProfile);
     mapDeviceToOutput(tabletId, DeviceType::Eraser, screenSpace, trackingMode, tabletProfile);
@@ -677,27 +622,23 @@ void TabletHandler::mapPenToScreenSpace(const QString &tabletId,
     d->profileManagerList.value(tabletId)->saveProfile(tabletProfile);
 }
 
-
-void TabletHandler::mapTabletToCurrentScreenSpace(const QString &tabletId,
-                                                  TabletProfile& tabletProfile)
+void TabletHandler::mapTabletToCurrentScreenSpace(const QString &tabletId, TabletProfile &tabletProfile)
 {
-    Q_D( TabletHandler );
+    Q_D(TabletHandler);
 
     DeviceProfile stylusProfile = tabletProfile.getDevice(DeviceType::Stylus);
-    DeviceProfile touchProfile  = tabletProfile.getDevice(DeviceType::Touch);
+    DeviceProfile touchProfile = tabletProfile.getDevice(DeviceType::Touch);
 
-    QString       stylusMode    = stylusProfile.getProperty(Property::Mode);
-    ScreenSpace   stylusSpace   = ScreenSpace(stylusProfile.getProperty(Property::ScreenSpace));
-    QString       touchMode     = touchProfile.getProperty(Property::Mode);
-    ScreenSpace   touchSpace    = ScreenSpace(touchProfile.getProperty(Property::ScreenSpace));
+    QString stylusMode = stylusProfile.getProperty(Property::Mode);
+    ScreenSpace stylusSpace = ScreenSpace(stylusProfile.getProperty(Property::ScreenSpace));
+    QString touchMode = touchProfile.getProperty(Property::Mode);
+    ScreenSpace touchSpace = ScreenSpace(touchProfile.getProperty(Property::ScreenSpace));
 
     mapDeviceToOutput(tabletId, DeviceType::Stylus, stylusSpace, stylusMode, tabletProfile);
     mapDeviceToOutput(tabletId, DeviceType::Eraser, stylusSpace, stylusMode, tabletProfile);
-    mapDeviceToOutput(tabletId, DeviceType::Touch,  touchSpace,  touchMode,  tabletProfile);
+    mapDeviceToOutput(tabletId, DeviceType::Touch, touchSpace, touchMode, tabletProfile);
 
     d->profileManagerList.value(tabletId)->saveProfile(tabletProfile);
 }
 
-
-
 #include "moc_tablethandler.cpp"
